package srtree;

import java.util.*;

/**
 * Implements a memory page file. Holds all pages into a Hashtable with keys equal to each object's
 * page number.
 * <p>
 * Created: Wed May 19 09:33:26 1999
 * <p>
 * @author Hadjieleftheriou Marios
 * @version 1.002
 */
public class MemoryPageFile extends PageFile {
    private Hashtable file = new Hashtable();

    protected void initialize(SRTree tree, int dimension, float fillFactor, int capacity, float branchFactor, int treeType) {
	super.initialize(tree, dimension, fillFactor, capacity, branchFactor, treeType);
	file.clear();
    }

    protected AbstractNode readNode(long page) throws PageFaultError {
	reads++;

	if (page < 0) {
	    throw new IllegalArgumentException("Page number cannot be negative.");
	}

	AbstractNode ret = (AbstractNode) file.get(new Long(page));

	if (ret == null) {
	    throw new PageFaultError("Invalid page number request.");
	}

	return ret;
    }

    protected long writeNode(AbstractNode n) throws PageFaultError {
	writes++;

	if (n == null) {
	    throw new IllegalArgumentException("Node cannot be null.");
	}

	long i = 0;
	if (n.pageNumber < 0) {
	    while (true) {
		if (! file.containsKey(new Long(i))) {
		    break;
		}
		i++;
	    }
	    n.pageNumber = i;
	} else {
	    i = n.pageNumber;
	}

	file.put(new Long(i), n);

	return i;
    }

    public void dumpFile() {
	for (Enumeration e = file.elements(); e.hasMoreElements();) {
	    System.out.println(e.nextElement());
	}
	System.out.println("Reads: " + reads + ", Writes: " + writes);
    }

} // MemoryPageFile
