package srtree;

/**
 * Abstract class for all classes implementing a storage manager for the RTree. Every node should be stored in
 * a unique page. The root node is always stored in page 0. The storage manager should have the control
 * over the page numbers where each node should be stored. 
 * <p>
 * Created: Tue May 18 16:24:00 1999
 * <p>
 * @author Hadjieleftheriou Marios
 * @version 1.003
 */
public abstract class PageFile {
    protected SRTree tree = null;

    /** Dimension of data inserted into the tree. */
    protected int dimension = -1;

    /** 
     * fillFactor specifies minimum node entries present in each node. It must be a float between
     * 0 and 0.5. 
     */
    protected float fillFactor = -1;

    protected float branchFactor = -1;

    /** Maximum node capacity. Each node will be able to hold at most nodeCapacity entries. */
    protected int nodeCapacity = -1;

    protected int treeType = -1;

    protected long reads = 0;

    protected long writes = 0;

    /**
     * Returns the node stored in the requested offset.
     */
    protected abstract AbstractNode readNode(long offset) throws PageFaultError;

    /**
     * Writes the node into the first available page and returns the offset of that page.
     */ 
    protected abstract long writeNode(AbstractNode o) throws PageFaultError;

    protected void initialize(SRTree tree, int dimension, float fillFactor, int capacity, float branchFactor, int treeType) {
	this.dimension = dimension;
	this.fillFactor = fillFactor;
	this.branchFactor = branchFactor;
	this.nodeCapacity = capacity;
	this.treeType = treeType;
	this.tree = tree;
    }

    protected void finalize() throws Throwable {
	super.finalize();
    }

    public abstract void dumpFile();

} // PageFile
